@@ -159,7 +159,7 @@ class AlephAPI(object):
             response = self.session.request(method=method, url=url, **kwargs)
             response.raise_for_status()
         except RequestException as exc:
-            raise AlephException(exc)
+            raise AlephException(exc) from exc
 
         if len(response.text):
             return response.json()
@@ -327,7 +327,7 @@ class AlephAPI(object):
                     entity, publisher=publisher, collection=collection
                 )
         except RequestException as exc:
-            raise AlephException(exc)
+            raise AlephException(exc) from exc
 
     def _bulk_chunk(
         self,
@@ -348,11 +348,44 @@ class AlephAPI(object):
                 ae = AlephException(exc)
                 if not ae.transient or attempt > self.retries:
                     if not force:
-                        raise ae
+                        raise ae from exc
                     log.error(ae)
                     return
                 backoff(ae, attempt)
 
+    def write_entity(
+        self, collection_id: str, entity: Dict, entity_id: str = None, **kw
+    ) -> None:
+        """Create a single entity via the API, in the given
+        collection.
+
+        params
+        ------
+        collection_id: id of the collection to use. This will overwrite any
+        existing collection specified in the entity dict
+        entity_id: id for the entity to be created. This will overwrite any
+        existing entity specified in the entity dict
+        entity: A dict object containing the values of the entity
+        """
+        entity["collection_id"] = collection_id
+        entity["id"] = entity_id
+
+        for attempt in count(1):
+            if entity_id is not None:
+                url = self._make_url("entities/{}").format(entity_id)
+            else:
+                url = self._make_url("entities")
+            try:
+                response = self.session.post(url, json=entity)
+                response.raise_for_status()
+                return
+            except RequestException as exc:
+                ae = AlephException(exc)
+                if not ae.transient or attempt > self.retries:
+                    log.error(ae)
+                    raise exc
+                backoff(ae, attempt)
+
     def write_entities(
         self, collection_id: str, entities: Iterable, chunk_size: int = 1000, **kw
     ):
@@ -387,12 +420,12 @@ class AlephAPI(object):
         if url is None:
             url = self._make_url("match")
         try:
-            response = self.session.post(url, json=entity, params=params)
+            response = self.session.post(url, json=entity, params=params)  # type: ignore
             response.raise_for_status()
             for result in response.json().get("results", []):
                 yield self._patch_entity(result, publisher=publisher)
         except RequestException as exc:
-            raise AlephException(exc)
+            raise AlephException(exc) from exc
 
     def entitysets(
         self,
@@ -455,7 +488,7 @@ class AlephAPI(object):
                     return self._request("POST", url, data=m, headers=headers)
             except AlephException as ae:
                 if not ae.transient or attempt > self.retries:
-                    raise ae
+                    raise ae from ae
                 backoff(ae, attempt)
         return {}
 
